package s.d.manager.model;

import java.util.ArrayList;
import java.util.List;

import org.eclipse.swt.SWT;
import org.eclipse.swt.custom.CCombo;
import org.eclipse.swt.custom.TableEditor;
import org.eclipse.swt.events.SelectionAdapter;
import org.eclipse.swt.events.SelectionEvent;
import org.eclipse.swt.graphics.Rectangle;
import org.eclipse.swt.layout.GridData;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Display;
import org.eclipse.swt.widgets.Event;
import org.eclipse.swt.widgets.Listener;
import org.eclipse.swt.widgets.Monitor;
import org.eclipse.swt.widgets.Shell;
import org.eclipse.swt.widgets.Table;
import org.eclipse.swt.widgets.TableColumn;
import org.eclipse.swt.widgets.TableItem;

import s.d.manager.model.ups.ClimatControl.InputsTableRow;
import s.d.manager.model.ups.ClimatControl.OutputsTableRow;
import s.d.manager.model.ups.ClimatControlUnit;
import s.d.manager.model.ups.PhaseParam;
import s.d.manager.model.ups.Relay;

public class Gui {
	
	public  Composite parent;

	public final int maxPswLenght = 4;
	
	private  List<TableEditor> editors = new ArrayList<TableEditor>();
	
	public Gui() {
		
	}
	
	public  Composite getParent() {
		return parent;
	}
	
	public  void setComposite(Composite parent) {
		this.parent = parent;
	}
	
	private  GridData getGridDataTable() {
		GridData data = new GridData(SWT.FILL, SWT.FILL, true, true);
		//data.heightHint = 200;
		return data;
	}
	
	public  Table createTable(String... titles) {
		Table table = null;
		try {
			if (getParent() != null) {
				table = new Table(getParent(), SWT.MULTI | SWT.BORDER | SWT.FULL_SELECTION);
				table.setLinesVisible(true);
				table.setHeaderVisible(true);
				table.setLayoutData(getGridDataTable());
				for (int i = 0; i < titles.length; i++) {
					TableColumn column = new TableColumn(table, SWT.NONE);
					column.setText(titles[i]);
					column.setWidth(75);
				}
			
			}
			//packColumns(table);
		} catch (Exception e) {
			e.printStackTrace();
		}
		return table;
	}
	
	public void setTableColumnWidths(Table table, int...widths) {
		if(table.getColumnCount()==widths.length) {
			for(int i=0; i<table.getColumnCount(); i++) {
				table.getColumn(i).setWidth(widths[i]);
				
			}
		}
	}
	
	private  List<TableEditor> getTableEditors() {
		return editors;
	}
	
	public  void fillRelaysTable(List<Relay> data, Table table) {
		if (data!= null) {
			for (int i = 0; i < data.size(); i++) {
				final TableItem item = new TableItem(table, SWT.NONE);
				item.setData(data.get(i));
				item.setText(0, Integer.toString(i+1));
				
				TableEditor editor = new TableEditor(table);
				getTableEditors().add(editor);
				final CCombo comboAssigment = new CCombo(table, SWT.NONE);
				
				for (String assigment : data.get(i).getRelayAssigmentConstants()) {
					comboAssigment.add(assigment);
				}
				
				comboAssigment.addSelectionListener(new SelectionAdapter() {
					public void widgetSelected(SelectionEvent e) {
						// .    1
						((Relay)item.getData()).setAssigment(comboAssigment.getSelectionIndex()+1);
					}
				});
				
				editor.grabHorizontal = true;
				editor.setEditor(comboAssigment, item, 1);

				editor = new TableEditor(table);
				getTableEditors().add(editor);
				final CCombo comboPolarity = new CCombo(table, SWT.NONE);
				for (String polarity : data.get(i).getRelayPolarityConstants()) {
					comboPolarity.add(polarity);
					
				}
				comboPolarity.addSelectionListener(new SelectionAdapter() {
					public void widgetSelected(SelectionEvent e) {
						((Relay)item.getData()).setPolarity(comboPolarity.getSelectionIndex());
					}
				});
				
				editor.grabHorizontal = true;
				editor.setEditor(comboPolarity, item, 2);
				
				//.    1
				
				table.getColumn(1).setWidth(230);
				if (data.get(i).getAssigment() != null) {
					comboAssigment.select(data.get(i).getAssigment()-1);
				}
				comboAssigment.pack();
				
				if (data.get(i).getPolarity() != null) {
					comboPolarity.select(data.get(i).getPolarity());
				}
				comboPolarity.pack();
				
				table.getColumn(0).pack();
				table.getColumn(2).pack();
			}
			
			table.redraw();

		}
	}
	
	public  void fillClimatControlUnitTable(List<ClimatControlUnit> data, Table table) {
		if (data!= null) {
			for (int i = 0; i < data.size(); i++) {
				final TableItem item = new TableItem(table, SWT.NONE);
				item.setData(data.get(i));
				
				item.setText(0,data.get(i).getClimatControlUnitAssigmentConstants().get(i));
				
				TableEditor editor = new TableEditor(table);
				getTableEditors().add(editor);
				final CCombo comboState = new CCombo(table, SWT.NONE);
				for (String state : data.get(i).getClimatControlUnitStateConstants()) {
					comboState.add(state);
					
				}
				comboState.addSelectionListener(new SelectionAdapter() {
					public void widgetSelected(SelectionEvent e) {
						((ClimatControlUnit)item.getData()).setState(comboState.getSelectionIndex());
					}
				});
				
				editor.grabHorizontal = true;
				editor.setEditor(comboState, item, 1);
				
				//.    1
				
				/*table.getColumn(1).setWidth(230);
				if (data.get(i).getAssigment() != null) {
					comboAssigment.select(data.get(i).getAssigment()-1);
				}
				comboAssigment.pack();*/
				table.getColumn(1).setWidth(230);
				if (data.get(i).getState() != null) {
					comboState.select(data.get(i).getState());
				}
				comboState.pack();
				
				/*table.getColumn(0).pack();
				table.getColumn(1).pack();
				*/table.pack();
			}
			
			table.redraw();

		}
	}
	
	public  void fillPhaseParamsTable(List<PhaseParam> data, Table table) {
		if (data != null) {
			for (int i = 0; i < data.size(); i++) {
				TableItem item = new TableItem(table, SWT.NONE);
				if (data.get(i) != null) {
					if (data.get(i).getUpsPhaseIndex()!=null) {
						item.setText(0, data.get(i).getUpsPhaseIndex());
					} else {
						item.setText(0, "n/a");
					}
					if (data.get(i).getUpsPhaseInVoltage() != null) {
						item.setText(1, data.get(i).getUpsPhaseInVoltage());
					} else {
						item.setText(1, "n/a"); 
					}
					if (data.get(i).getUpsPhaseFrequency() != null) {
						item.setText(2, data.get(i).getUpsPhaseFrequency());
					} else {
						item.setText(2, "n/a");
					}
					if (data.get(i).getUpsPhaseOutCurrent() != null) {
						item.setText(4, data.get(i).getUpsPhaseOutCurrent());
					} else {
						item.setText(4, "n/a");
					}
					if (data.get(i).getUpsPhaseOutVoltage() != null) {
						item.setText(3, data.get(i).getUpsPhaseOutVoltage());
					} else {
						item.setText(3, "n/a");
					}
				} else {				
					item.setText(0, "n/a");
					item.setText(1, "n/a");
					item.setText(2, "n/a");
					item.setText(3, "n/a");
					item.setText(4, "n/a");					
				}
			}
			table.redraw();
		} else {		
			TableItem item = new TableItem(table, SWT.NONE);
			item.setText(0, "n/a");
			item.setText(1, "n/a");
			item.setText(2, "n/a");
			item.setText(3, "n/a");
			item.setText(4, "n/a");
		}			
		table.redraw();
		table.getParent().getParent().getParent().pack();
	}
	
	public  void fillClimaticInputTable(List<InputsTableRow> data, Table table) {
		if (data != null & table!=null) {
			for (int i = 0; i < data.size(); i++) {
				TableItem item = new TableItem(table, SWT.NONE);
				if (data.get(i) != null) {
					if (data.get(i).getInputType()!=null) {
						item.setText(0, data.get(i).getInputType().toString());
					} else {
						item.setText(0, "n/a");
					}
					if (data.get(i).getInputFlag() != null) {
						item.setText(1, data.get(i).getInputFlag().toString());
					} else {
						item.setText(1, "n/a"); 
					}
					if (data.get(i).getInputAssigment() != null) {
						item.setText(2, data.get(i).getInputAssigment());
					} else {
						item.setText(2, "n/a");
					}
					if (data.get(i).getInputDelay() != null) {
						item.setText(3, data.get(i).getInputDelay().toString());
					} else {
						item.setText(3, "n/a");
					}
	
				} else {				
					item.setText(0, "n/a");
					item.setText(1, "n/a");
					item.setText(2, "n/a");
					item.setText(3, "n/a");
					//item.setText(4, "n/a");					
				}
			}
			table.redraw();
		} else if (table!=null){		
			TableItem item = new TableItem(table, SWT.NONE);
			item.setText(0, "n/a");
			item.setText(1, "n/a");
			item.setText(2, "n/a");
			item.setText(3, "n/a");
			//item.setText(4, "n/a");
		}			
		table.redraw();
		//table.getParent().getParent().getParent().pack();
	}
	
	/*public static String unHex(String arg) {        

	    String str = "";
	    for(int i=0;i<arg.length();i+=2)
	    {
	        String s = arg.substring(i, (i + 2));
	        int decimal = Integer.parseInt(s, 16);
	        str = str + (char) decimal;
	    }       
	    return str;
	}*/
	
	public  void fillClimaticOutputTable(List<OutputsTableRow> data, Table table) {
		if (data != null) {
			for (int i = 0; i < data.size(); i++) {
				TableItem item = new TableItem(table, SWT.NONE);
				if (data.get(i) != null) {
					if (data.get(i).getOutputFlag()!=null) {
						item.setText(0, data.get(i).getOutputFlag().toString());
					} else {
						item.setText(0, "n/a");
					}
					if (data.get(i).getOutputAssigment() != null) {
						item.setText(1, data.get(i).getOutputAssigment().toString());
					} else {
						item.setText(1, "n/a"); 
					}
				} else {				
					item.setText(0, "n/a");
					item.setText(1, "n/a");					
				}
			}
			table.redraw();
		} else {		
			TableItem item = new TableItem(table, SWT.NONE);
			item.setText(0, "n/a");
			item.setText(1, "n/a");
		}			
		table.redraw();
		table.getParent().getParent().getParent().pack();
	}
	
	public  void packColumns(Table table) {
		try {
			for (int i = 0; i < table.getColumnCount(); i++) {
				table.getColumn(i).pack();
				
			}
		} catch (Exception e) {
			e.printStackTrace();
		}
	}
	
	public  void centerShell(Shell shell) {
		try {			
			Monitor primary = Display.getDefault().getPrimaryMonitor();
		    Rectangle bounds = primary.getBounds();
		    Rectangle rect = shell.getBounds();
		    int x = bounds.x + (bounds.width - rect.width) / 2;
		    int y = bounds.y + (bounds.height - rect.height) / 2;
		    shell.setLocation(x, y);		
		} catch (Exception e) {
			e.printStackTrace();
		}

	}
	
	public  void centerShell(Shell shell, int offset) {
		try {
			
			Monitor primary = Display.getDefault().getPrimaryMonitor();
		    Rectangle bounds = primary.getBounds();
		    Rectangle rect = shell.getBounds();
		    int x = bounds.x + (bounds.width - rect.width) / 2;
		    int y = bounds.y + (bounds.height - rect.height) / 2;
		    shell.setLocation(x, y + offset);
		
		} catch (Exception e) {
			e.printStackTrace();
		}

	}
	
	public  void clearTable(Table table) {
		try {
			//      TableEditor
			for (TableEditor editor : getTableEditors()) {
				editor.getEditor().dispose();
			}
			getTableEditors().clear();
			
			table.clearAll();
			table.removeAll();
		} catch (Exception e) {
			e.printStackTrace();
		}
	}
	
	public Listener getPswListener() {
		Listener listener = new Listener () {
            public void handleEvent (Event e) {
                String string = e.text;
                char [] chars = new char [string.length ()];
                string.getChars (0, chars.length, chars, 0);
                for (int i=0; i<chars.length; i++) {
                    if (!('0' <= chars [i] && chars [i] <= '9')) {
                    	e.doit = false;
                        return;
                    }
                }
            }
		};
		return listener;
	}
	
	public Shell createOsSpecificDialog () {
		
		String operatingSystem = System.getProperty("os.name");   
	    if (operatingSystem.contains("Linux")) {
	    	return new Shell(Application.getInstance().display, SWT.DIALOG_TRIM|SWT.APPLICATION_MODAL);//Linux kde,gnome  	
	    }
	    else if (operatingSystem.contains("Windows")) {
	    	return new Shell(Application.getInstance().display, SWT.SHELL_TRIM | SWT.TOOL | SWT.ON_TOP |SWT.APPLICATION_MODAL );	        
	    }
	    else {
	    	return new Shell(Application.getInstance().display, SWT.SHELL_TRIM | SWT.TOOL | SWT.ON_TOP |SWT.APPLICATION_MODAL );
	        //throw new RuntimeException("Unsupported operating system.");
	    }
	}
}
