package s.d.manager.snmp;

import java.io.ByteArrayOutputStream;
import java.io.IOException;
import java.net.InetAddress;
import java.net.UnknownHostException;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;

import org.snmp4j.CommunityTarget;
import org.snmp4j.PDU;
import org.snmp4j.Snmp;
import org.snmp4j.Target;
import org.snmp4j.TransportMapping;
import org.snmp4j.event.ResponseEvent;
import org.snmp4j.mp.SnmpConstants;
import org.snmp4j.smi.Address;
import org.snmp4j.smi.GenericAddress;
import org.snmp4j.smi.Integer32;
import org.snmp4j.smi.IpAddress;
import org.snmp4j.smi.OID;
import org.snmp4j.smi.OctetString;
import org.snmp4j.smi.TimeTicks;
import org.snmp4j.smi.UdpAddress;
import org.snmp4j.smi.Variable;
import org.snmp4j.smi.VariableBinding;
import org.snmp4j.transport.DefaultUdpTransportMapping;
import org.snmp4j.util.DefaultPDUFactory;
import org.snmp4j.util.PDUFactory;
import org.snmp4j.util.TableEvent;
import org.snmp4j.util.TableUtils;
public class SnmpShtyl {
	protected String address;
	protected String port;
	protected String communityRead;
	protected String communityWrite;
	protected String host;
	private Boolean errorConnection = false;
	private UdpAddress udpAddress;
	private Boolean gettingIpByNameIsFailed = true;
	//@Inject
	
	public SnmpShtyl(String address, String port, String communityRead, String communityWrite){
	    setAddress(getIpByName(address));
		setPort(port);
		setCommunityRead(communityRead);
		setCommunityWrite(communityWrite);
		setHost(getAddress(), getPort());
		setUdpAddress();
		
	}
	
	public String getIpByName(String address) {
		InetAddress ipAddress;
		String result = null;
		try {
			ipAddress = InetAddress.getByName(address);
			result = ipAddress.getHostAddress();
		} catch (UnknownHostException e) {
			// TODO Auto-generated catch block
			//wanIpAddress = null;
			//e.printStackTrace();
			//result = false;
			gettingIpByNameIsFailed = true;
			return result;
		}
		gettingIpByNameIsFailed = false;
		return result;
	}
	
	public void dispose(){
		address = null;
		port = null;
		communityRead = null;
		host = null; 
		errorConnection = null;
		//listener = null;
		//broker = null;
		udpAddress = null;
	}
	private void setAddress(String address){
		this.address = address;
	}
	
	public String getAddress(){
		return address;
		
	}
	
	public String getPort(){
		return port;
		
	}
	private void setPort(String port){
		this.port = port;
	}
	
	private void setCommunityRead(String community){
		this.communityRead = community;
	}
	
	public String getCommunityRead(){
		return communityRead;
	}
	
	private void setCommunityWrite(String community){
		this.communityWrite = community;
	}
	
	public String getCommunityWrite(){
		return communityWrite;
	}
	
	private void setHost(String address, String port){
		this.host = address + "/" + port;
	}
	
	private String getHost(){
		return host;
	}
	
	public Boolean getErrorConnection() {
		return errorConnection;
	}

	private void setErrorConnection(Boolean errorConnection) {
		this.errorConnection = errorConnection;
	}
	
	public Boolean checkIp(String ip){
		Boolean flag =false;  
		try{
			new UdpAddress( ip + "/" + getPort());
			flag = true;
		} catch (Exception e){
			flag = false;
		}
		
		return flag;	
	}
	
	public Boolean setUdpAddress(){
		Boolean flag =false;  
		this.udpAddress = null;
		try{
			this.udpAddress = new UdpAddress(getHost());
			flag = true;
		} catch (Exception e){
			flag = false;
		}
		return flag;
	}
	private UdpAddress getUdpAddress(){
		return udpAddress;
	}
	
	private Target getTargetRead() { 
		
		CommunityTarget comtarget = new CommunityTarget();
		try{
		     comtarget.setCommunity(new OctetString(getCommunityRead()));
		     comtarget.setVersion(SnmpConstants.version1);
		     comtarget.setAddress(getUdpAddress());
		     comtarget.setRetries(2);
		     comtarget.setTimeout(1000);
		     return comtarget;
		}catch(Exception e){
			e.printStackTrace();
		}
		return comtarget;
		
	}
	
	private Target getTargetWrite() {
		CommunityTarget comtarget = new CommunityTarget();
		try{
		     comtarget.setCommunity(new OctetString(getCommunityWrite()));
		     comtarget.setVersion(SnmpConstants.version1);
		     comtarget.setAddress(getUdpAddress());
		     comtarget.setRetries(2);
		     comtarget.setTimeout(2000);
		     return comtarget;
		}catch(Exception e){
			e.printStackTrace();
		}
		return comtarget;
		
	}
	
	private PDU setPDU(int pduType, OID oidValue){
		 PDU pdu = new PDU();
	     pdu.add(new VariableBinding(new OID(oidValue)));
	     pdu.setType(pduType);
	     pdu.setRequestID(new Integer32(1));
		return pdu;
	}
	
	private TransportMapping getTransport(){
		TransportMapping transport = null;
		try {
			transport = new DefaultUdpTransportMapping();
		} catch (IOException e1) {
			// TODO Auto-generated catch block
			e1.printStackTrace();
		}
		try {
			transport.listen();
		} catch (IOException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}
		return transport;
	}
	
	private PDUFactory getPDUFactory(){
		 PDUFactory pduFactory = new DefaultPDUFactory (PDU.GETNEXT);
		return pduFactory;
	}
	
	public List<List<String>> getTableAsStrings(String... columns) {
	    
		OID[] columnsOids = new OID[columns.length];
		for (int i=0; i<columns.length; i++) {
			columnsOids[i] = new OID(columns[i]);
		}
		
		Snmp snmp = new Snmp(getTransport());
		TableUtils tUtils = new TableUtils(snmp, new DefaultPDUFactory());

	    List<TableEvent> events = tUtils.getTable(getTargetRead(), columnsOids, null, null);

	    List<List<String>> list = new ArrayList<List<String>>();
	    for (TableEvent event : events) {
	        if (event.isError()) {
	            System.err.println(event);
	            continue;
	            // throw new
	            // RuntimeException(event.getErrorMessage(),event.getException());
	        }
	        List<String> strList = new ArrayList<String>();
	        list.add(strList);
	        for (VariableBinding vb : event.getColumns()) {
	            strList.add(vb.getVariable().toString());
	        }
	    }
	    try{
			snmp.close();
		} catch ( IOException e ) {
			
		}
	    return list;
	}
	
	public List<TableEvent> getTable(String upsPhaseParamsTable){
		
		if (gettingIpByNameIsFailed == true) {
			setErrorConnection(true);
			return null;
		}
		
		Snmp snmp = new Snmp(getTransport());
		OID[] columns = new OID[1];
		columns[0] = new OID(upsPhaseParamsTable);
		List<TableEvent> snmpList  = null;
		if (setUdpAddress()) {
			try { 
				snmp.listen();
				TableUtils tableUtils = new TableUtils(snmp, getPDUFactory());
				snmpList = tableUtils.getTable(getTargetRead(), columns, null, null);
				if (snmpList.get(0).getStatus() != PDU.noError) {
					snmpList = null;
				}
			}catch(Exception e){
				snmpList = null;
			}
			
			try{
				snmp.close();
			} catch ( IOException e ) {
				
			}
		}
		
		return snmpList;	
	}
	
	public List<TableEvent> getTable(String... columns){
		
		if (gettingIpByNameIsFailed == true) {
			setErrorConnection(true);
			return null;
		}
		Snmp snmp = new Snmp(getTransport());
		OID[] columnsOids = new OID[columns.length];
		for (int i=0; i<columns.length; i++) {
			columnsOids[i] = new OID(columns[i]);
		}
		List<TableEvent> tableEvents  = null;
		if (setUdpAddress()) {
			try {  
				snmp.listen();
				TableUtils tableUtils = new TableUtils(snmp, getPDUFactory());
				tableEvents = tableUtils.getTable(getTargetRead(), columnsOids, null, null);
				if (tableEvents.get(0).getStatus() != PDU.noError) {
					tableEvents = null;
				}
			} catch(Exception e) {
				tableEvents = null;
			}
			
			try {
				snmp.close();
			} catch ( IOException e ) {
				
			}
		}
		
		return tableEvents;	
	}
	
	public String getAsString(String oidValue){
		
		if (gettingIpByNameIsFailed == true) {
			setErrorConnection(true);
			return null;
		}
		
		Snmp snmp = new Snmp(getTransport());
		setErrorConnection(false);
		String value = null;
		ResponseEvent response = null;
		PDU responsePDU = null;
	     try {
	    	 response = snmp.get(setPDU(PDU.GET, new OID(oidValue)), getTargetRead());
	     } catch (IOException e) {
			
	     }
	    
	     if (response != null){
	    	 responsePDU = response.getResponse();
	    	 if (responsePDU != null) {
	    		 int errorStatus = responsePDU.getErrorStatus();
	    		 if (errorStatus == PDU.noError){
	    			 try{
	    				 value = response.getResponse().get(0).getVariable().toString();
	    			 } catch(Exception e){
	    				 value = null;
	    			 }
	    		 }else{
	    			 value = null;
	    			 setErrorConnection(true);
	    		 }
	    	 }else{
	    		 value = null;
	    		 setErrorConnection(true);
	    	 }
	     }else{
	    	 value = null; 
	    	 setErrorConnection(true);
	     }
	     try {
			snmp.close();
			if (responsePDU != null) {
	    		 responsePDU.clear();
	    	 }
	     } catch (IOException e) {

		}
		return value;
	}
	
	public List<String> getAsString(String ...oids){
		
		if (gettingIpByNameIsFailed == true) {
			setErrorConnection(true);
			return null;
		}
		
		Snmp snmp = new Snmp(getTransport());
		PDU pdu = new PDU();
		List<String> values =  new ArrayList<String>();
		for (String oid : oids) {
			pdu.add(new VariableBinding(new OID(oid)));
		}
		pdu.setType(PDU.GET);
		ResponseEvent event = null;
		try {
			event = snmp.send(pdu, getTargetRead(), null);
		} catch (IOException e) {
			event = null;
			setErrorConnection(true);
		}
		if(event != null) {
			setErrorConnection(false);
			if (event.getResponse()!=null){
				if (event.getRequest().getErrorStatus()== PDU.noError){
					for (int i=0; i<event.getResponse().size() ;i++){
						try{
							values.add(event.getResponse().get(i).getVariable().toString());
						}catch (Exception e){
							values.clear();
							values = null;
							setErrorConnection(true);
						}
					}
				}else{
					values.clear();
					values = null;
					setErrorConnection(true);
				}
			}else{
				values.clear();
				values = null;
				setErrorConnection(true);
			}
			
		} else{
			setErrorConnection(true);
		}
		try{
			snmp.close();
			if (pdu != null) {
				pdu.clear();
			}
		} catch ( IOException e ) {
			
		}
		return values;
		//throw new RuntimeException("GET timed out");
		}
	
	public void sendTrap(String trapOid, String valueOid, String value, String address, int port) {
		
		PDU pdu = new PDU();
		//PDU pdu = (PDU) DefaultPDUFactory.createPDU(SnmpConstants.version2c);
		pdu.setType(PDU.TRAP);
		pdu.add(new VariableBinding(SnmpConstants.sysUpTime, new TimeTicks(30000)));
		pdu.add(new VariableBinding(SnmpConstants.snmpTrapOID, new OID(trapOid)));
		
		pdu.add(new VariableBinding(SnmpConstants.snmpTrapAddress, new IpAddress("")));
		//String ipAddress = GenericAddress.parse("udp:192.168.0.63/162").toString().split("/")[0];
		//pdu.add(new VariableBinding(SnmpConstants.snmpTrapAddress, new IpAddress(GenericAddress.parse("udp:192.168.0.63/162").toString().split("/")[0])));
		pdu.add(new VariableBinding(SnmpConstants.snmpTrapAddress, new IpAddress(GenericAddress.parse("udp:"+address+"/"+port).toString().split("/")[0])));
		pdu.add(new VariableBinding(new OID(valueOid), new OctetString(value)));
		
		CommunityTarget cTarget = new CommunityTarget();
		cTarget.setCommunity(new OctetString("public"));
		cTarget.setVersion(SnmpConstants.version2c);
		//cTarget.setAddress(GenericAddress.parse("udp:192.168.0.63/162"));//new UdpAddress(address + "/" + 162));
		cTarget.setAddress(GenericAddress.parse("udp:"+address+"/"+port));//new UdpAddress(address + "/" + 162));
		cTarget.setRetries(2);
		cTarget.setTimeout(5000);
		
		Snmp snmp = new Snmp(getTransport());		
		System.out.println("Sending V2 Trap");		
		try {
			snmp.send(pdu, cTarget);
		} catch (IOException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}		
		try {
			snmp.close();
		} catch (IOException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}

	}
	
	public List<Integer> getAsInt(List<String> oids){
		if (gettingIpByNameIsFailed == true) {
			setErrorConnection(true);
			return null;
		}
		
		Snmp snmp = new Snmp(getTransport());
		List<Integer> values = new ArrayList<Integer>();
		PDU pdu = new PDU();
		for (String oid : oids) {
			pdu.add(new VariableBinding(new OID(oid)));
		}
		pdu.setType(PDU.GET);
		ResponseEvent event = null;
		try {
			event = snmp.send(pdu, getTargetRead());
		} catch (IOException e) {
			setErrorConnection(true);
			event = null;
		}
		if(event != null) {
			setErrorConnection(false);
			if (event.getResponse()!=null){
				if (event.getRequest().getErrorStatus()== PDU.noError){
					for (int i=0; i<event.getResponse().size() ;i++){
						try{
							values.add(event.getResponse().get(i).getVariable().toInt());	
						}catch (Exception e){
							values.clear();
							values = null;
							setErrorConnection(true);
						}
					}
				} else {
					values.clear();
					values = null;
					setErrorConnection(true);
				}
			} else {
				values.clear();
				values = null;
				setErrorConnection(true);
			}
		}
		try {
			snmp.close();//  !    -  .
			if (pdu != null) {
				pdu.clear();
				pdu = null;
			}
		} catch ( IOException e ) {
			
		}
		return values;
	}
	
	public List<Variable> getAsObjectList(List<String> oids){
		if (gettingIpByNameIsFailed == true) {
			setErrorConnection(true);
			return null;
		}
		
		Snmp snmp = new Snmp(getTransport());
		List<Variable> values = new ArrayList<Variable>();
		PDU pdu = new PDU();
		for (String oid : oids) {
			pdu.add(new VariableBinding(new OID(oid)));
		}
		pdu.setType(PDU.GET);
		ResponseEvent event = null;
		try {
			event = snmp.send(pdu, getTargetRead());
		} catch (IOException e) {
			setErrorConnection(true);
			event = null;
		}
		if(event != null) {
			setErrorConnection(false);
			if (event.getResponse()!=null){
				if (event.getRequest().getErrorStatus()== PDU.noError){
					for (int i=0; i<event.getResponse().size() ;i++){
						try{
							values.add(event.getResponse().get(i).getVariable());	
						}catch (Exception e){
							values.clear();
							values = null;
							setErrorConnection(true);
						}
					}
				} else {
					values.clear();
					values = null;
					setErrorConnection(true);
				}
			} else {
				values.clear();
				values = null;
				setErrorConnection(true);
			}
		}
		try {
			snmp.close();//  !    -  .
			if (pdu != null) {
				pdu.clear();
				pdu = null;
			}
		} catch ( IOException e ) {
			
		}
		return values;
	}
	
	public List<Integer> getAsInt(String ...oids){
		
		if (gettingIpByNameIsFailed == true) {
			setErrorConnection(true);
			return null;
		}
		
		Snmp snmp = new Snmp(getTransport());
		List<Integer> values = new ArrayList<Integer>();
		PDU pdu = new PDU();
		for (String oid : oids) {
			pdu.add(new VariableBinding(new OID(oid)));
		}
		pdu.setType(PDU.GET);
		ResponseEvent event = null;
		try {
			event = snmp.send(pdu, getTargetRead());
		} catch (IOException e) {
			setErrorConnection(true);
			event = null;
		}
		if(event != null) {
			setErrorConnection(false);
			if (event.getResponse()!=null){
				if (event.getRequest().getErrorStatus()== PDU.noError){
					for (int i=0; i<event.getResponse().size() ;i++){
						try{
							values.add(event.getResponse().get(i).getVariable().toInt());	
						}catch (Exception e){
							values.clear();
							values = null;
							setErrorConnection(true);
						}
					}
				} else {
					values.clear();
					values = null;
					setErrorConnection(true);
				}
			} else {
				values.clear();
				values = null;
				setErrorConnection(true);
			}
		}
		try {
			snmp.close();//  !    -  .
			if (pdu != null) {
				pdu.clear();
				pdu = null;
			}
		} catch ( IOException e ) {
			
		}
		return values;
	}
	
	public Integer getAsInt(String oidValue) {
		if (gettingIpByNameIsFailed == true) {
			setErrorConnection(true);
			return null;
		} else {
		
		Snmp snmp = new Snmp(getTransport());
		Integer value = null;
	    ResponseEvent response = null;
	    PDU responsePDU = null;
		try {
			response = snmp.get(setPDU(PDU.GET, new OID(oidValue)), getTargetRead());
		} catch (IOException e) {
			value = null;
		}
	    if (response != null) {
	    	responsePDU = response.getResponse();
			if (responsePDU != null) {
				int errorStatus = responsePDU.getErrorStatus();
				   if (errorStatus == PDU.noError) {
					   try{
						   value = response.getResponse().get(0).getVariable().toInt();
					   } catch(Exception e){
						   value = null;
					   }
				   } else {
					   value = null;
					   setErrorConnection(true);
				   }
			 } else {
				 value = null;
				 setErrorConnection(true);
			 }
	   } else {
	       setErrorConnection(true);
	       value = null;
	   }
	   try {	
	    	 snmp.close();
	    	 if (responsePDU != null) {
	    		 responsePDU.clear();
	    	 }
	   } catch (IOException e) {
			e.printStackTrace();
	   }
	   return value;
		}
	}
	
	public void Stop(){
	
	}
	
	/*public void GetAsStringAsynchronous(final OID oidValue){
		  final Snmp snmp = new Snmp(getTransport());
		 //errorConnection = false;
		 //String value = null;
		// System.out.println("Sending Request to Agent...");
		 
		 ResponseListener listener = new ResponseListener() {
		     public void onResponse(ResponseEvent event) {
		       // Always cancel async request when response has been received
		       // otherwise a memory leak is created! Not canceling a request
		       // immediately can be useful when sending a request to a broadcast
		       // address.
		       //((Snmp)event.getSource()).cancel(event.getRequest(), this);
		       
		       ResponseEvent response = null;
				try {
					response = snmp.get(setPDU(PDU.GET, oidValue), getTargetRead());
				} catch (IOException e) {
					// TODO Auto-generated catch block
					//e.printStackTrace();
				}

			     // Process Agent Response
				
			     if (response != null)
			     {
			      // System.out.println("Got Response from Agent");
			       //PDU responsePDU = response.getResponse();/////// !
			    	 PDU responsePDU = event.getResponse();
			       if (responsePDU != null)
			       {
			         int errorStatus = responsePDU.getErrorStatus();
			         //int errorIndex = responsePDU.getErrorIndex();
			         //String errorStatusText = responsePDU.getErrorStatusText();

			         if (errorStatus == PDU.noError)
			         {
			           //System.out.println("Snmp Get Response = " + responsePDU.getVariableBindings());
			           //value = response.getResponse().get(0).getVariable().toString();
			        	 //Application.broker.post(EventConstants.REQUEST_ALARM,  event.getResponse().get(0).getVariable().toString());
			           //Application.broker.post(EventConstants.REQUEST_ALARM, response.getResponse().get(0).getVariable().toString());
			        	 setErrorConnection(true);
			         }
			         else
			         {
			           System.out.println("Error: Request Failed");
			           System.out.println("Error Status = " + errorStatus);
			           System.out.println("Error Index = " + errorIndex);
			           System.out.println("Error Status Text = " + errorStatusText);
			        	// System.out.println("Error Status = " + errorStatus);
			        	// value = "  PDU";
			           setErrorConnection(true);
			         }
			       }
			       else
			       {
			        // System.out.println("Error: Response PDU is null");
			         //value = "PDU = null";
			         setErrorConnection(true);
			       }
			     }
			     else
			     {
			       //System.out.println("Error: Agent Timeout... ");
			       //value = "   ";
			       setErrorConnection(true);
			       //((Snmp)event.getSource()).cancel(event.getRequest(), this);
			     }
			     //Application.broker.post(EventConstants.REQUEST_ALARM,  event.getResponse().get(0).getVariable().toString()); 
		       //System.out.println("Received response PDU is: "+event.getResponse().get(0).getVariable().toString());
		       //((Snmp)event.getSource()).cancel(event.getRequest(), this);
		     }
		   };
		   try {
			   snmp.send(setPDU(PDU.GET, oidValue), getTargetRead(), null, listener);
		   } catch (IOException e) {
			   // TODO Auto-generated catch block
			   e.printStackTrace();
			  // System.out.println("  snmp.send ");
		   }
		   try {
		    	 snmp.close();
		   } catch (IOException e) {
				// TODO Auto-generated catch block
				e.printStackTrace();
		   }
	     
		//return value;
	}*/
	
	/*public Boolean set(String oidValue, String communityWrite, String value){
		Snmp snmp = new Snmp(getTransport());
	    PDU response = null;
		PDU pdu = new PDU();
	    pdu.add(new VariableBinding( new OID(oidValue), new OctetString(value)));
	    pdu.setType(PDU.SET);
	    boolean success = false;
		    try {
				response = snmp.set(pdu, getTargetWrite()).getResponse();
				if (response!= null){
					if (response.getErrorStatus() == PDU.noError){
						success = true;
					} else {
						success = false;
					}
				}else{
					success = false;
				}
				
			} catch (IOException e) {
				success = false;
			}
	        
	        try {
				snmp.close();
			} catch (IOException e) {
				
			}
	    try {
	    	 snmp.close();
	   } catch (IOException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
	   }
		return success;
	    
	}*/
	
	public void set(String oidValue, String communityWrite, String value) {
		
		if (gettingIpByNameIsFailed == true) {
			setErrorConnection(true);
			//return null;
			return;
		}
		
		if (value != null) {
			Snmp snmp = new Snmp(getTransport());
			PDU pdu = new PDU();
		    pdu.add(new VariableBinding( new OID(oidValue), new OctetString(value)));
		    pdu.setType(PDU.SET);
		    try {
		    	snmp.set(pdu, getTargetWrite()).getResponse();	
			} catch (Exception e) {
				
			}
	        try {
				snmp.close();
				if (pdu != null) {
					pdu.clear();
				}
				
			} catch (Exception e) {
				
			}  
		}
	}
	
	public void set(String oidValue, String communityWrite, Integer value) {
		
		if (gettingIpByNameIsFailed == true) {
			setErrorConnection(true);
			return;
		}
		
		if (value != null) {
			Snmp snmp = new Snmp(getTransport());
			PDU pdu = new PDU();
		    pdu.add(new VariableBinding( new OID(oidValue), new Integer32(value)));
		    pdu.setType(PDU.SET);
		    try {
		    	snmp.set(pdu, getTargetWrite()).getResponse();	
			} catch (Exception e) {
				
			}
	        try {
				snmp.close();
				if (pdu != null) {
					pdu.clear();
				}
			} catch (Exception e) {
				
			}  
		}
	}
	
	/*public void set(List<String> oids, String communityWrite, List<String> values) {
		Snmp snmp = new Snmp(getTransport());
		PDU pdu = new PDU();
		for (int i= 0; i < oids.size(); i++) {
			pdu.add(new VariableBinding( new OID(oids.get(i)), new OctetString(values.get(i))));
		}
	    pdu.setType(PDU.SET);
	  
	    try {
	    	snmp.set(pdu, getTargetWrite());
	    	//snmp.s
		} catch (IOException e) {
			
		}
       
        try {
			snmp.close();
			pdu.clear();
		} catch (IOException e) {
			
		}
	}*/
	
	/*public Boolean set(String oidValue, String communityWrite, Integer value){
		Snmp snmp = new Snmp(getTransport());
		//System.out.println("Sending Request to Agent...");
	    PDU response = null;
		PDU pdu = new PDU();
	    pdu.add(new VariableBinding( new OID(oidValue), new Integer32(value)));
	    pdu.setType(PDU.SET);
	    boolean success = false;
	   // if (setUdpAddress()){//    
		    try {
				response = snmp.set(pdu, getTargetWrite()).getResponse();
				if (response!= null) {
					if (response.getErrorStatus() == PDU.noError){
						success = true;
					} else {
						success = false;
					}
				} else {
					success = false;
				}
				
			} catch (IOException e) {
				// TODO Auto-generated catch block
				//System.out.println("");
				//e.printStackTrace();
				success = false;
			}
	        if (response!= null) {
	        	response.getErrorIndex();
	        	response.getErrorStatus();
	        	response.getErrorStatusText();
	        	System.out.println("Set Status is: "+response.getErrorStatusText());
	        	
	        }
	        try {
				snmp.close();
			} catch (IOException e) {
				// TODO Auto-generated catch block
				//e.printStackTrace();
			}
	   // }
	    try {
	    	 snmp.close();
	   } catch (IOException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
	   }
		return success;
	    
	}*/
}
